@@ -2,13 +2,9 @@ import datetime
 import json
 import os
 
-from .utils import (
-    names_to_abbreviations,
-    process_variables,
-    suck_out_editions,
-    suck_out_formats,
-    suck_out_variations_only,
-)
+from .utils import (names_to_abbreviations, process_variables,
+                    suck_out_editions, suck_out_formats,
+                    suck_out_variations_only)
 
 
 def datetime_parser(dct):
